@@ -10,7 +10,7 @@ import time
 from collections import defaultdict
 from datetime import datetime
 
-from snazzy import colors_enabled, green, red, yellow
+from snazzy import emoji, green, red, yellow
 from stressor.config_manager import ConfigManager
 from stressor.monitor.server import MonitorServer
 from stressor.plugins.base import register_plugins
@@ -81,7 +81,9 @@ class RunManager:
         self.options = self.DEFAULT_OPTS.copy()
         self.stage = "ready"
         self.start_dt = None
+        self.start_stamp = None
         self.end_dt = None
+        self.end_stamp = None
 
         register_plugins()
         self.CURRENT_RUN_MANAGER = self
@@ -169,14 +171,16 @@ class RunManager:
     def get_cli_summary(self):
         cm = self.config_manager
         lines = []
-
+        run_time = self.end_stamp - self.start_stamp
+        user_count = len(self.session_list)
         has_errors = self.has_errors()
 
         ap = lines.append
         col = red if has_errors else green
+        horz_line = col("=-" * 38 + "=")
 
         ap("Result Summary:")
-        ap(col("=-" * 35))
+        ap(horz_line)
         ap("Stressor scenario '{}' finished.".format(cm.name))
         ap("  Tag:      '{}'".format(cm.get("tag", "n.a.")))
         ap("  Base URL: {}".format(cm.config.get("base_url", "")))
@@ -184,19 +188,53 @@ class RunManager:
         ap("  End:      {}".format(self.end_dt.strftime("%Y-%m-%d %H:%M:%S")))
         ap(
             "Run time {}, net: {}.".format(
-                self.end_dt - self.start_dt,
+                format_elap(run_time, high_prec=True),
                 format_elap(self.stats["net_act_time"], high_prec=True),
             )
         )
         ap(
             "Executed {:,} activities in {:,} sequences, using {:,} parallel sessions.".format(
-                self.stats["act_count"],
-                self.stats["seq_count"],
-                len(self.session_list),
+                self.stats["act_count"], self.stats["seq_count"], user_count,
             )
         )
+        if run_time:
+            ap(
+                "Sequence duration: {} average.".format(
+                    format_elap(run_time / self.stats["seq_count"], high_prec=True)
+                )
+            )
+            ap(
+                "             rate: {:,.3f} sequences per minute (per user: {:,.3f}).".format(
+                    60.0 * self.stats["seq_count"] / run_time,
+                    60.0 * self.stats["seq_count"] / (run_time * user_count),
+                )
+            )
+            ap(
+                "Activity rate:     {:,.3f} activities per second (per user: {:,.3f}).".format(
+                    self.stats["act_count"] / run_time,
+                    self.stats["act_count"] / (run_time * user_count),
+                )
+            )
+
+        # --- List of all activities that are marked `monitor: true`
+        if self.stats["monitored"]:
+            print(self.stats["monitored"])
+            ap("{} monitored activities:".format(len(self.stats["monitored"])))
+            for path, info in self.stats["monitored"].items():
+                errors = info.get("errors")
+                ap("  - {}".format(path))
+                ap(
+                    "    n: {:,}, min: {}, avg: {}, max: {}{}".format(
+                        info["act_count"],
+                        format_elap(info["act_time_min"], high_prec=True),
+                        format_elap(info["act_time_avg"], high_prec=True),
+                        format_elap(info["act_time_max"], high_prec=True),
+                        red(", {} errors".format(errors)) if errors else "",
+                    )
+                )
+
         if has_errors:
-            pics = " 💥 💔 💥" if colors_enabled() else ""
+            pics = emoji(" 💥 💔 💥", "")
             ap(
                 red(
                     "Result: ERROR, found {:,} errors and {:,} warnings.".format(
@@ -205,16 +243,17 @@ class RunManager:
                     + pics
                 )
             )
-            if self.stats.stats["max_error_reached"]:
+            if self.stats.stats["run_limit_reached"]:
                 ap(
                     yellow(
-                        "Some activities where skipped due to the `fail_on_errors` limit."
+                        "Some activities where skipped due to the `max-errors` "
+                        " or `max-time` limit."
                     )
                 )
         else:
-            pics = " ✨ 🍰 ✨" if colors_enabled() else ""
+            pics = emoji(" ✨ 🍰 ✨", "")
             ap(green("Result: Ok." + pics))
-        ap(col("=-" * 35))
+        ap(horz_line)
         return "\n".join(lines)
 
     def get_status_info(self):
@@ -376,8 +415,10 @@ class RunManager:
             time.sleep(0.5)
             monitor.open_browser()
 
+        self.start_stamp = time.monotonic()
         self.start_dt = datetime.now()
         self.end_dt = None
+        self.end_stamp = None
         try:
             try:
                 res = False
@@ -388,13 +429,14 @@ class RunManager:
                 self.stop()
             finally:
                 self.end_dt = datetime.now()
+                self.end_stamp = time.monotonic()
 
             if self.options.get("log_summary", True):
                 logger.important(self.get_cli_summary())
 
             if monitor:
                 self.set_stage("waiting")
-                logger.important("Press Ctrl+C to quit.")
+                logger.important("Waiting for monitor... Press Ctrl+C to quit.")
                 self.stop_request.wait()
         finally:
             if monitor:
@@ -411,3 +453,6 @@ class RunManager:
         self.set_stage("stopping")
         self.stop_request.set()
         return True
+
+    def get_run_time(self):
+        return time.monotonic() - self.start_stamp
